==> jc-1.4.0.tar.gz: java/security/AccessController.h <==
// public final class java.security.AccessController

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 93cafe227fbda1e java_security_AccessController

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_AccessController_H_
#define _JC_java_security_AccessController_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_AccessControlContext$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PrivilegedAction$object;
struct _jc_java_security_PrivilegedExceptionAction$object;

// Typedefs
typedef struct _jc_java_security_AccessController$sub_refs	_jc_java_security_AccessController$sub_refs;
typedef struct _jc_java_security_AccessController$sub_nonrefs	_jc_java_security_AccessController$sub_nonrefs;
typedef struct _jc_java_security_AccessController$refs	_jc_java_security_AccessController$refs;
typedef struct _jc_java_security_AccessController$nonrefs	_jc_java_security_AccessController$nonrefs;
typedef struct _jc_java_security_AccessController$object	_jc_java_security_AccessController$object;

typedef const struct _jc_java_security_AccessController$vmethods	_jc_java_security_AccessController$vmethods;
typedef const struct _jc_java_security_AccessController$vtable	_jc_java_security_AccessController$vtable;
typedef const struct _jc_java_security_AccessController$vtype	_jc_java_security_AccessController$vtype;

// Constructors
extern void _jc_java_security_AccessController$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_AccessController$object *);

// Static methods
extern void _jc_java_security_AccessController$method$checkPermission$c9030844da652e90(_jc_env *, struct _jc_java_security_Permission$object *);
extern struct _jc_java_lang_Object$object *_jc_java_security_AccessController$method$doPrivileged$8b5d3f6ed937bde6(_jc_env *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_java_security_AccessController$method$doPrivileged$54e88eab423007ef(_jc_env *, struct _jc_object *, struct _jc_java_security_AccessControlContext$object *);
extern struct _jc_java_lang_Object$object *_jc_java_security_AccessController$method$doPrivileged$6cd480e578eaa024(_jc_env *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_java_security_AccessController$method$doPrivileged$e39e5e9cd7414ebb(_jc_env *, struct _jc_object *, struct _jc_java_security_AccessControlContext$object *);
extern struct _jc_java_security_AccessControlContext$object *_jc_java_security_AccessController$method$getContext$ed3d42e32d89c9e4(_jc_env *);

// Virtual methods structure
struct _jc_java_security_AccessController$vmethods {
};

// Vtable
struct _jc_java_security_AccessController$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AccessController$vmethods	java_security_AccessController;
};

// Vtype
struct _jc_java_security_AccessController$vtype {
	_jc_type			type;
	_jc_java_security_AccessController$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AccessController$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_AccessController$refs {
    _jc_java_security_AccessController$sub_refs	java_security_AccessController;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AccessController$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AccessController$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AccessController$sub_nonrefs	java_security_AccessController;
};

// Object instance structure
struct _jc_java_security_AccessController$object {
	_jc_java_security_AccessController$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AccessController$vtype	*vtype;
	_jc_java_security_AccessController$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AccessController$vtype _jc_java_security_AccessController$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AccessController, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AccessController$class_object;

#endif	/* _JC_java_security_AccessController_H_ */

==> jc-1.4.6.tar.gz: java/security/AccessController.h <==
// public final class java.security.AccessController

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 93cafe227fbda1e java_security_AccessController

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_AccessController_H_
#define _JC_java_security_AccessController_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_AccessControlContext$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PrivilegedAction$object;
struct _jc_java_security_PrivilegedExceptionAction$object;

// Typedefs
typedef struct _jc_java_security_AccessController$sub_refs	_jc_java_security_AccessController$sub_refs;
typedef struct _jc_java_security_AccessController$sub_nonrefs	_jc_java_security_AccessController$sub_nonrefs;
typedef struct _jc_java_security_AccessController$refs	_jc_java_security_AccessController$refs;
typedef struct _jc_java_security_AccessController$nonrefs	_jc_java_security_AccessController$nonrefs;
typedef struct _jc_java_security_AccessController$object	_jc_java_security_AccessController$object;

typedef const struct _jc_java_security_AccessController$vmethods	_jc_java_security_AccessController$vmethods;
typedef const struct _jc_java_security_AccessController$vtable	_jc_java_security_AccessController$vtable;
typedef const struct _jc_java_security_AccessController$vtype	_jc_java_security_AccessController$vtype;

// Constructors
extern void _jc_java_security_AccessController$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_AccessController$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_security_AccessController$method$checkPermission$c9030844da652e90(_jc_env *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_security_AccessController$method$doPrivileged$8b5d3f6ed937bde6(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_security_AccessController$method$doPrivileged$54e88eab423007ef(_jc_env *, struct _jc_object *, struct _jc_java_security_AccessControlContext$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_security_AccessController$method$doPrivileged$6cd480e578eaa024(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_security_AccessController$method$doPrivileged$e39e5e9cd7414ebb(_jc_env *, struct _jc_object *, struct _jc_java_security_AccessControlContext$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_AccessControlContext$object *_jc_java_security_AccessController$method$getContext$ed3d42e32d89c9e4(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_AccessController$vmethods {
};

// Vtable
struct _jc_java_security_AccessController$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AccessController$vmethods	java_security_AccessController;
};

// Vtype
struct _jc_java_security_AccessController$vtype {
	_jc_type			type;
	_jc_java_security_AccessController$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AccessController$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_AccessController$refs {
    _jc_java_security_AccessController$sub_refs	java_security_AccessController;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AccessController$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AccessController$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AccessController$sub_nonrefs	java_security_AccessController;
};

// Object instance structure
struct _jc_java_security_AccessController$object {
	_jc_java_security_AccessController$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AccessController$vtype	*vtype;
	_jc_java_security_AccessController$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AccessController$vtype _jc_java_security_AccessController$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AccessController, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AccessController$class_object;

#endif	/* _JC_java_security_AccessController_H_ */
